%bcond_with doc

%define _smp_ncpus_max 4

Name: libical
Version: 3.0.9
Release: %mkrel 1
Summary: An implementation of basic iCAL protocols
License: LGPLv2+
Group: System/Libraries
Url: https://github.com/libical/libical
Source0: https://github.com/libical/libical/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires: flex
BuildRequires: bison
BuildRequires: cmake
%if %{with doc}
BuildRequires: gtk-doc
%endif
BuildRequires: icu-devel
BuildRequires: vala
BuildRequires: pkgconfig(glib-2.0)
BuildRequires: pkgconfig(gobject-introspection-1.0)
BuildRequires: pkgconfig(libxml++-2.6)

%description
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

#------------------------------------------------------

%define major 3
%define libname %mklibname ical %{major}

%package -n %{libname}
Summary: Files for developing applications that use libical
Group: System/Libraries

%description -n %{libname}
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

%files -n %{libname}
%{_libdir}/libical.so.%{major}{,.*}
%{_libdir}/libical_cxx.so.%{major}{,.*}

#------------------------------------------------------

%define girmajor 3.0
%define girname %mklibname ical-gir %{girmajor}

%package -n %{girname}
Summary: GObject Introspection interface description for ICal
Group: System/Libraries
Requires: %{libname} = %{version}-%{release}
Conflicts: %{_lib}ical3 < 3.0.5-5

%description -n %{girname}
GObject Introspection interface description for ICal.

%files -n %{girname}
%{_libdir}/girepository-1.0/ICal-%{girmajor}.typelib

#------------------------------------------------------

%define libnamess %mklibname icalss %{major}

%package -n %{libnamess}
Summary: Files for developing applications that use libical
Group: System/Libraries

%description -n %{libnamess}
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

%files -n %{libnamess}
%{_libdir}/libicalss.so.%{major}{,.*}
%{_libdir}/libicalss_cxx.so.%{major}{,.*}

#------------------------------------------------------

%define libnameglib %mklibname ical-glib %{major}

%package -n %{libnameglib}
Summary: Files for developing applications that use libical
Group: System/Libraries

%description -n %{libnameglib}
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

%files -n %{libnameglib}
%{_libdir}/libical-glib.so.%{major}{,.*}

#------------------------------------------------------

%define girmajorglib 3.0
%define girnameglib %mklibname icalglib-gir %{girmajorglib}

%package -n %{girnameglib}
Summary: GObject Introspection interface description for ICalGLib
Group: System/Libraries
Requires: %{libnameglib} = %{version}-%{release}
Conflicts: %{_lib}ical-glib3 < 3.0.5-5

%description -n %{girnameglib}
GObject Introspection interface description for ICalGLib.

%files -n %{girnameglib}
%{_libdir}/girepository-1.0/ICalGLib-%{girmajorglib}.typelib

#------------------------------------------------------

%define libnamevcal %mklibname icalvcal %{major}

%package -n %{libnamevcal}
Summary: Files for developing applications that use libical
Group: System/Libraries

%description -n %{libnamevcal}
Libical is an Open Source implementation of the IETF's iCalendar
Calendaring and Scheduling protocols (RFC 2445, 2446, and 2447).
It parses iCal components and provides a C API for manipulating
the component properties, parameters, and subcomponents.

%files -n %{libnamevcal}
%{_libdir}/libicalvcal.so.%{major}{,.*}

#------------------------------------------------------

%define develname %mklibname ical -d

%package -n %{develname}
Summary:	Files for developing applications that use libical
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libnamess} = %{version}-%{release}
Requires:	%{libnamevcal} = %{version}-%{release}
Requires:	%{libnameglib} = %{version}-%{release}
Requires:	%{girname} = %{version}-%{release}
Requires:	%{girnameglib} = %{version}-%{release}
Conflicts:	%{_lib}ical3 < 3.0.5-5
Conflicts:	%{_lib}ical-glib3 < 3.0.5-5

%description -n %{develname}
The header files and libtool library for
developing applications that use libical.

%files -n %{develname}
%doc TODO TEST THANKS
%doc doc/UsingLibical*
%if %{with doc}
%doc %{_datadir}/gtk-doc/html/%{name}-glib/
%endif
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_libdir}/cmake/LibIcal
%{_datadir}/gir-1.0/ICal-%{girmajor}.gir
%{_datadir}/gir-1.0/ICalGLib-%{girmajorglib}.gir
%{_datadir}/vala/vapi/libical-glib.vapi

#------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%cmake \
  -DICAL_ERRORS_ARE_FATAL:BOOL=false \
  -DGOBJECT_INTROSPECTION:BOOL=true \
  -DSHARED_ONLY:BOOL=true \
  -DENABLE_GTK_DOC:BOOL=%{?with_doc:true}%{?!with_doc:false} \
  -DICAL_GLIB_VAPI:BOOL=true

# avoid parallel-builds, gir generatation fails on slower archs
%cmake_build -j1

%install
%cmake_install

# This is just a private build tool, not meant to be installed
rm %{buildroot}/%{_libexecdir}/libical/ical-glib-src-generator


%changelog
* Sat Jan 23 2021 luigiwalser <luigiwalser> 3.0.9-1.mga8
+ Revision: 1673025
- 3.0.9
- remove upstream patches

* Wed Dec 02 2020 daviddavid <daviddavid> 3.0.8-6.mga8
+ Revision: 1651539
- add openmandriva patch to fix build with icu 68
- rebuild for new icu 68.1

* Tue Nov 17 2020 luigiwalser <luigiwalser> 3.0.8-5.mga8
+ Revision: 1646889
- add upstream patch to fix reading newer tzdata (mga#27473)

* Tue Nov 03 2020 luigiwalser <luigiwalser> 3.0.8-4.mga8
+ Revision: 1642212
- add fedora patches per suggestion from evolution developer

* Wed Jul 01 2020 wally <wally> 3.0.8-3.mga8
+ Revision: 1601034
- rebuild for icu 67.1

* Sat Apr 04 2020 wally <wally> 3.0.8-2.mga8
+ Revision: 1564470
- rebuild for new icu 66.1

* Tue Mar 17 2020 luigiwalser <luigiwalser> 3.0.8-1.mga8
+ Revision: 1557473
- 3.0.8

* Tue Feb 18 2020 umeabot <umeabot> 3.0.7-2.mga8
+ Revision: 1540276
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Dec 15 2019 kekepower <kekepower> 3.0.7-1.mga8
+ Revision: 1467608
- Update to version 3.0.7

* Sun Nov 17 2019 daviddavid <daviddavid> 3.0.6-1.mga8
+ Revision: 1461417
- new version: 3.0.6

* Sat Oct 05 2019 daviddavid <daviddavid> 3.0.5-6.mga8
+ Revision: 1449447
- rebuild for new icu 65.1

* Thu Aug 08 2019 tv <tv> 3.0.5-5.mga8
+ Revision: 1428121
- limit max cpu in order to fix build
+ wally <wally>
- build with recommended icu
- enable vala support
- add conditional for libical-glib gtk-doc build (and disable it)
- move libical-glib gtk-doc to devel pkg
- split out gir typelibs
- move gir files to devel pkg

* Wed Aug 07 2019 tv <tv> 3.0.5-4.mga8
+ Revision: 1427885
- enable introspection support (needed for new evolution-data-server)

* Wed Aug 07 2019 tv <tv> 3.0.5-3.mga8
+ Revision: 1427875
- make devel requires ical-glib (needed for new evolution-data-server)

* Wed Aug 07 2019 tv <tv> 3.0.5-2.mga8
+ Revision: 1427871
- remove static files (break new evolution-data-server)

* Sat Jul 13 2019 daviddavid <daviddavid> 3.0.5-1.mga8
+ Revision: 1420904
- new version: 3.0.5

* Sun Sep 23 2018 umeabot <umeabot> 3.0.4-2.mga7
+ Revision: 1298910
- Mageia 7 Mass Rebuild

* Tue Aug 21 2018 kekepower <kekepower> 3.0.4-1.mga7
+ Revision: 1253331
- Update to version 3.0.4

* Sat Apr 07 2018 kekepower <kekepower> 3.0.3-2.mga7
+ Revision: 1215967
- BR gtk-doc

* Thu Apr 05 2018 zezinho <zezinho> 3.0.3-1.mga7
+ Revision: 1215516
- new version 3.0.3 - remove upstreamed patches - add glib component

* Fri Mar 23 2018 wally <wally> 2.0.0-4.mga7
+ Revision: 1211529
- drop BR on db4-devel (as it seems to be unused and upstream says db support might be buggy)

* Fri Dec 29 2017 luigiwalser <luigiwalser> 2.0.0-3.mga7
+ Revision: 1186864
- add upstream patches to fix CVE-2016-582[3-7] and CVE-2016-9584

* Thu Feb 11 2016 umeabot <umeabot> 2.0.0-2.mga6
+ Revision: 955565
- Mageia 6 Mass Rebuild

* Mon Jan 25 2016 luigiwalser <luigiwalser> 2.0.0-1.mga6
+ Revision: 927249
- 2.0.0
- library majors are now 2
- add patches from fedora to fix arm build and missing function

* Sun Jun 21 2015 luigiwalser <luigiwalser> 1.0.1-1.mga6
+ Revision: 837338
- fix source URL and actually upload tarball
- 1.0.1

* Wed Oct 15 2014 umeabot <umeabot> 1.0-4.mga5
+ Revision: 742800
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0-3.mga5
+ Revision: 681525
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.0-2.mga4
+ Revision: 525685
- Mageia 4 Mass Rebuild

* Sat Jun 01 2013 sander85 <sander85> 1.0-1.mga4
+ Revision: 434120
- New version: 1.0

* Sat Jan 12 2013 umeabot <umeabot> 0.48-2.mga3
+ Revision: 357476
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 03 2012 fwang <fwang> 0.48-1.mga2
+ Revision: 189864
- new version 0.48

* Sat Jan 15 2011 mikala <mikala> 0.46-1.mga1
+ Revision: 18564
- Drop mdk macros
- Remove BuildRoot
- imported package libical


* Sat Sep 18 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.46-1mdv2011.0
+ Revision: 579724
- update to new version 0.46

* Mon Jan 04 2010 Emmanuel Andry <eandry@mandriva.org> 0.44-1mdv2010.1
+ Revision: 486241
- New version 0.44

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0.43-3mdv2010.0
+ Revision: 425565
- rebuild

* Wed Feb 18 2009 Götz Waschk <waschk@mandriva.org> 0.43-2mdv2009.1
+ Revision: 342342
- disable fatal errors for e-d-s

* Thu Jan 15 2009 Frederic Crozat <fcrozat@mandriva.com> 0.43-1mdv2009.1
+ Revision: 329792
- Release 0.43
- Patch0: fix format security error

* Mon Nov 03 2008 Helio Chissini de Castro <helio@mandriva.com> 0.41-1mdv2009.1
+ Revision: 299524
- Update ical to current version, now finally cmake based

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - update to new version 0.33

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 0.31-2mdv2009.0
+ Revision: 267817
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu Apr 17 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.31-1mdv2009.0
+ Revision: 195308
- add missing buildrequires on bison
- new version

* Sun Feb 03 2008 Funda Wang <fwang@mandriva.org> 0.30-1mdv2008.1
+ Revision: 161695
- Br flex
- New version 0.30

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 20 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.27-3mdv2008.1
+ Revision: 110798
- obsolete really ancient libical devel package (with mdk tag ;)
- SILENt this is not needed also

* Tue Nov 20 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.27-2mdv2008.1
+ Revision: 110618
- add more explicit provides on devel package
- import libical


